#
# spec file for package libshumate
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 1
%define sominor 0
%define soname libshumate-%{somajor}_%{sominor}-1
%bcond_with profiling

Name:           libshumate
Version:        1.2.1
Release:        1.1
Summary:        C library providing a GtkWidget to display maps
License:        Apache-2.0 AND LGPL-2.1-or-later AND BSD-3-Clause AND CC0-1.0 AND CC-BY-3.0 AND GFDL-1.2-only
URL:            https://wiki.gnome.org/Projects/libshumate
Source:         %{name}-%{version}.tar.zst

BuildRequires:  gperf
BuildRequires:  gtk-doc >= 1.9
BuildRequires:  meson >= 0.53.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo) >= 1.4
BuildRequires:  pkgconfig(gi-docgen) >= 2021.1
BuildRequires:  pkgconfig(gio-2.0) >= 2.16.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.16.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.16.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.6.3
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libprotobuf-c)
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.0
BuildRequires:  pkgconfig(sqlite3) >= 1.12.0
BuildRequires:  pkgconfig(vapigen) >= 0.11.0
%if %{with profiling}
BuildRequires:  pkgconfig(sysprof-capture-4)
%endif

%description
libshumate is a C library providing a GtkWidget to display maps.
It supports numerous free map sources such as OpenStreetMap,
OpenCycleMap, OpenAerialMap and Maps for free.

libshumate is named after Jessamine Shumate, an American artist,
historian, and cartographer (Wikipedia). libshumate is forked from,
and tries to follow similar principles in the API as libchamplain.

%package -n %{soname}
Summary:        Shared library for %{name}
Provides:       %{name} = %{version}

%description -n %{soname}
C library providing a GtkWidget to display maps.
This package contains the shared library files.

%package -n typelib-1_0-Shumate-%{somajor}_%{sominor}
Summary:        Introspection file for %{name}

%description -n typelib-1_0-Shumate-%{somajor}_%{sominor}
C library providing a GtkWidget to display maps.
This package contains introspection file for %{name}.

%package devel
Summary:        Development files for %{name}
Requires:       %{soname} = %{version}
Requires:       typelib-1_0-Shumate-%{somajor}_%{sominor} = %{version}

%description devel
C library providing a GtkWidget to display maps.
This package contains development files for %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D vector_renderer=true \
	-D gtk_doc=true \
	-D sysprof=%{?with_profiling:enabled}%{!?with_profiling:disabled} \
	%{nil}
%meson_build

%install
%meson_install
%find_lang shumate%{somajor} %{?no_lang_C}

%ldconfig_scriptlets -n %{soname}

%files -n %{soname}
%license COPYING
%{_libdir}/libshumate-%{somajor}.%{sominor}.so.*

%files -n typelib-1_0-Shumate-%{somajor}_%{sominor}
%{_libdir}/girepository-1.0/Shumate-%{somajor}.%{sominor}.typelib

%files devel
%doc AUTHORS README.md
%{_datadir}/doc/libshumate-%{somajor}.%{sominor}/
%{_includedir}/shumate-%{somajor}.%{sominor}/
%{_libdir}/pkgconfig/shumate-%{somajor}.%{sominor}.pc
%{_libdir}/libshumate-%{somajor}.%{sominor}.so
%{_datadir}/gir-1.0/Shumate-%{somajor}.%{sominor}.gir
%{_datadir}/vala/vapi/shumate-%{somajor}.%{sominor}.deps
%{_datadir}/vala/vapi/shumate-%{somajor}.%{sominor}.vapi

%files lang -f shumate%{somajor}.lang

%changelog
* Thu May  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.1:
  + Fix compiling with C++.
  + Fix crash with null reference map source.
* Sat Mar 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.0:
  + Use g_assert_true instead of g_assert in tests.
  + Updated translations.
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.rc2:
  + Fix regression in vector renderer with the latest optimizations
    causing the hightway shield renderer in Maps not showing
    shields.
  + Fix compiling new tests with gcc using
  - Wimplicit-function-declaration.
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.rc:
  + Performance improvements to the vector renderer.
  + Remove undefined tile API.
  + Fix zooming with smooth scrolling mice.
  + Updated translations.
* Sun Feb 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.beta:
  + Fix artifacts in NGL renderer.
  + Don't crash in vector reader if key is NULL.
  + Enable the vector renderer by default when building (can still
    be disabled if not needed).
  + Add distance method for Location.
* Sat Feb 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.alpha:
  + Various vector renderer improvements.
  + Support continous scroll.
  + Support arrow key panning.
- Drop -D libsoup3=true mesom paraameter: no longer supported.
* Fri Feb 16 2024 Lubos Kocman <lubos.kocman@suse.com>
- Update licenses based on legaldb review
* Thu Nov  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.2:
  + Fix using overlay map layers with different tile sizes than the
    reference source.
* Sun Oct 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.1:
  + Fix null reference map source, avoid critical log message when
    setting a null map source with
    shumate_viewport_set_reference_map_source().
* Sat Sep 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.0:
  + Fix grey background on sprites
  + Updated translations.
- Switch compression to zst in both service and tarball produced.
* Wed Sep  6 2023 Luciano Santos <luc14n0@opensuse.org>
- Add with(out) "profiling" build switch and disable it, by
  default, as profiling isn't meant for general use. Add nested
  pkgconfig(sysprof-capture-4) BuildRequires under an if-with
  expression and pass sysprof=(enabled|disabled) to meson,
  depending on the profiling switch. This is meant for an eventual
  need for Sysprof's profiling support.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.rc:
  + Bugfixes and optimizations in vector render.
  + Add icon-color property for vector renderer.
  + Disable g_asserts on release builds.
  + Updated translations.
* Fri Aug 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.beta:
  + Vector rendering improvements.
  + Updated translations.
- Add pkgconfig(gperf) BuildRequires, a new introduced dependency.
* Wed Jul 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.5:
  + Don't defer frame clock when widget is unrealized.
* Tue Jul 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.4:
  + Throttle tile download during animations.
* Fri Dec  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.3:
  + Fix memory leaks.
  + Remove old tiles more aggresively, speeding up zoom animations.
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.2:
  + Avoid flickering when panning the map.
  + Fix warnings about min/max zoom levels for the viewport.
  + Fix documentation comments.
  + Fix cross-compilation for gi-docgen.
* Tue Oct 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Stop passing b_coverage=true to meson. We do not need the
  coverage tracking, that is for upstream developers.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.1:
  + Release 1.0.1 to avoid Meson considering 1.0.0 < 1.0.0.beta.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.0:
  + Fix build error with Clang.
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add libshumate Provides to shared library to make -lang package
  installable.
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.0.beta:
  + Finalized 1.0.0 API/ABI.
  + Various code cleanups.
  + Enabled localization support.
  + Changed the URL template for map sources.
- Add pkgconfig(json-glib-1.0) and pkgconfig(libprotobuf-c)
  BuildRequires, new dependencies.
- Pass vector_renderer=true, b_coverage=true and gtk_doc=true to
  meson, follow what upstream uses for checkin build tests, without
  the build fails....
- Package translations in new lang sub-package.
* Fri Jan 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE, version 1.0.0.alpha.1
